.. _utilipy-decorators-baseclass:

*****************************************************
Decorators Baseclass (`utilipy.decorators.baseclass`)
*****************************************************

.. currentmodule:: utilipy.decorators.baseclass



Reference/API
=============

.. automodapi:: utilipy.decorators.baseclass
